@@ -25,9 +25,17 @@ def create_permission_groups(sender, **kwargs):
     admin_group.permissions.add(delete_flagged_comment_perm)
 
 
+def adjust_flagged_comments(sender, **kwargs):
+    from comment.models import Comment
+    for comment in Comment.objects.all():
+        if not comment.is_flagged:
+            comment.flag.toggle_flagged_state()
+
+
 class CommentConfig(AppConfig):
     name = 'comment'
     verbose_name = 'comment'
 
     def ready(self):
         post_migrate.connect(create_permission_groups, sender=self)
+        post_migrate.connect(adjust_flagged_comments, sender=self)
